summaryrefslogtreecommitdiffstats
path: root/chrome/browser/profile.h
diff options
context:
space:
mode:
authorsky@google.com <sky@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-09-11 15:22:32 +0000
committersky@google.com <sky@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-09-11 15:22:32 +0000
commitd8e41ed4a55e60be60d47de5bbcb8a027e85a879 (patch)
treee0feaa030fe3834c0fc871de7564ef74e9595b05 /chrome/browser/profile.h
parent7903e0262e2dda44eaa186d126cf88e2cc1470eb (diff)
downloadchromium_src-d8e41ed4a55e60be60d47de5bbcb8a027e85a879.zip
chromium_src-d8e41ed4a55e60be60d47de5bbcb8a027e85a879.tar.gz
chromium_src-d8e41ed4a55e60be60d47de5bbcb8a027e85a879.tar.bz2
Renames BoomarkBarModel to BookmarkModel.
BUG=none TEST=none Review URL: http://codereview.chromium.org/1912 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@2057 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/profile.h')
-rw-r--r--chrome/browser/profile.h14
1 files changed, 5 insertions, 9 deletions
diff --git a/chrome/browser/profile.h b/chrome/browser/profile.h
index 9e5adf2..83dcdec 100644
--- a/chrome/browser/profile.h
+++ b/chrome/browser/profile.h
@@ -19,7 +19,7 @@
#include "chrome/personalization/personalization.h"
#endif
-class BookmarkBarModel;
+class BookmarkModel;
class DownloadManager;
class HistoryService;
class NavigationController;
@@ -182,11 +182,8 @@ class Profile {
// Returns true if the last time this profile was open it was exited cleanly.
virtual bool DidLastSessionExitCleanly() = 0;
- // Returns true if the BookmarkBarMOdel has been created.
- virtual bool HasBookmarkBarModel() = 0;
-
- // Returns the BookmarkBarModel, creating if not yet created.
- virtual BookmarkBarModel* GetBookmarkBarModel() = 0;
+ // Returns the BookmarkModel, creating if not yet created.
+ virtual BookmarkModel* GetBookmarkModel() = 0;
#ifdef CHROME_PERSONALIZATION
virtual ProfilePersonalization GetProfilePersonalization() = 0;
@@ -263,8 +260,7 @@ class ProfileImpl : public Profile {
virtual void UnregisterNavigationController(NavigationController* controller);
virtual const Profile::ProfileControllerSet& GetNavigationControllers();
virtual bool DidLastSessionExitCleanly();
- virtual bool HasBookmarkBarModel();
- virtual BookmarkBarModel* GetBookmarkBarModel();
+ virtual BookmarkModel* GetBookmarkModel();
virtual bool IsSameProfile(Profile* profile);
virtual Time GetStartTime() const;
virtual TabRestoreService* GetTabRestoreService();
@@ -297,7 +293,7 @@ class ProfileImpl : public Profile {
scoped_ptr<PrefService> prefs_;
scoped_ptr<TemplateURLFetcher> template_url_fetcher_;
scoped_ptr<TemplateURLModel> template_url_model_;
- scoped_ptr<BookmarkBarModel> bookmark_bar_model_;
+ scoped_ptr<BookmarkModel> bookmark_bar_model_;
#ifdef CHROME_PERSONALIZATION
ProfilePersonalization personalization_;